function [data, auxData, metaData, txtData, weights] = mydata_Boops_boops

%% set metaData
metaData.phylum     = 'Chordata'; 
metaData.class      = 'Actinopterygii'; 
metaData.order      = 'Spariformes'; 
metaData.family     = 'Sparidae';
metaData.species    = 'Boops_boops'; 
metaData.species_en = 'Bogue'; 
metaData.T_typical  = C2K(18); % K, body temp
metaData.data_0     = {'ab'; 'ap'; 'am'; 'Lb'; 'Lp'; 'Li'; 'Wwb'; 'Wwp'; 'Wwi'; 'Ri'}; 
metaData.data_1     = {'t-L', 'L-Ww'}; 

metaData.COMPLETE = 2.5; % using criteria of LikaKear2011

metaData.author   = {'Houria Handjar'};    
metaData.date_subm = [2015 04 21];              
metaData.email    = {'handjarhouria@gmail.com'};            
metaData.address  = {'Tiaret, 14000, Algeria'};   

metaData.author_mod_1   = {'Bas Kooijman'};    
metaData.date_mod_1 = [2015 10 21];              
metaData.email_mod_1    = {'bas.kooijman@vu.nl'};            
metaData.address_mod_1  = {'VU University Amsterdam'};  

metaData.curator     = {'Starrlight Augustine'};
metaData.email_cur   = {'starrlight.augustine@akvaplan.niva.no'}; 
metaData.date_acc    = [2015 11 02]; 


%% set data
% zero-variate data

data.ab = 4;    units.ab = 'd';    label.ab = 'age at birth';               bibkey.ab = 'Hour2015';   
  temp.ab = C2K(18);  units.temp.ab = 'K'; label.temp.ab = 'temperature';
data.ap = 540;    units.ap = 'd';    label.ap = 'age at puberty';           bibkey.ap = 'Hour2015';
  temp.ap = C2K(18);  units.temp.ap = 'K'; label.temp.ap = 'temperature';
data.am = 2920;    units.am = 'd';    label.am = 'life span';               bibkey.am = 'Hour2015';   
  temp.am = C2K(18);  units.temp.am = 'K'; label.temp.am = 'temperature'; 

data.Lb  = 0.26;   units.Lb  = 'cm';  label.Lb  = 'total length at birth';  bibkey.Lb  = 'Hour2015';
data.Lp  = 17;   units.Lp  = 'cm';  label.Lp  = 'total length st puberty';  bibkey.Lp  = 'Hour2015';
data.Li  = 28.42;   units.Li  = 'cm';  label.Li  = 'ultimate total length'; bibkey.Li  = 'Hour2015';

data.Wwb = 5.24e-4;   units.Wwb = 'g';   label.Wwb = 'wet weight at birth'; bibkey.Wwb = 'Hour2015';
data.Wwp = 44.5;   units.Wwp = 'g';   label.Wwp = 'wet weight at puberty';  bibkey.Wwp = 'Hour2015';
data.Wwi = 216;   units.Wwi = 'g';   label.Wwi = 'ultimate wet weight';     bibkey.Wwi = 'Hour2015';

data.Ri  = 430;   units.Ri  = '#/d'; label.Ri  = 'maximum reprod rate';     bibkey.Ri  = 'Hour2015';   
  temp.Ri = C2K(18);  units.temp.Ri = 'K'; label.temp.Ri = 'temperature';
 
% uni-variate data
% t-L data
data.tL = [365	730	1095 1460 1825 2190;    % d, time since birth
           14	20	23	25	26	28]';  % cm, total length at f and T
units.tL   = {'d', 'cm'};  label.tL = {'time since birth', 'total length'};  
temp.tL    = C2K(18);  units.temp.tL = 'K'; label.temp.tL = 'temperature';
bibkey.tL = 'fishbase';
comment.tL = 'total length and wet weight were measured at the same time';
  
data.LW = [17.4	17.3	18.5	16.4	17.7	20.2	16	18	20	18.2	19.6	17.4	20	19	20.7	15.8	17	21.5	18.2	18.6	17.5	16.5	19	19.5	15	20.4	18	17	17.8	15.7	19.3	16	15.6	18	15.6	16	17	19	15	17.5	21.5	19.4	24.4	16.4	16.8	17.5	17.8	17.8	15.5	19.2	18	16.7	17.5	15.2	17.8	16.5	17.4	19	10.7	18	17.8	15.7	18	18	17	17	11.6	17.5	17.5	17.4	12	15.5	15.7	10.8	19	18.8	17.5	20.1	20.6	18.7	18.2	17	16.6	17.6	16.2	17.7	16.4	18.8	19	17.1	16.8	18	10.3	11.1	10.1	9.2	20.3	20.2	17	24.7	21	21.7	20.2	23.5	19.7	16.2	17.8	18.5	17.6	20.8	13.5	11.8	17.1	17.8	16.8	16.9	14.7	14.9	16.1	17.1	17.3	16.5	17.6	14.5	24.6	27.4	18.1	21.9	19.9	23.7	22	20.3	18	18.2	21.5	20	15	16.5	18.5	17	15	18	23.5	16.5	16.2	17.5	17.8	16.8	19	17.3	16.5	15.5	17.8	17.5	18	20.3	19.5	20	11.2	17	17.6	22	18.5	19.5	19	18.2	18.5	19.3	22.5	23.2;      % cm, total length at f
           38.0	45.0	49.0	33.0	44.0	72.0	32.0	43.0	55.0	45.0	65.0	45.0	71.0	63.0	69.0	33.0	39.0	76.0	50.0	62.0	53.0	41.0	58.0	71.0	30.0	72.0	55.0	48.0	49.0	36.0	67.0	39.0	39.0	60.0	33.0	40.0	44.0	63.0	31.0	51.0	83.0	66.0	135.0	37.0	44.0	48.0	54.0	50.0	33.0	73.0	50.0	43.0	50.0	29.0	49.0	40.0	51.0	66.0	8.5	55.0	50.0	33.0	53.0	52.0	49.0	42.0	11.0	45.0	50.0	47.0	15.0	33.0	36.0	8.0	59.0	55.0	43.0	75.0	66.0	54.0	56.0	42.0	41.0	50.0	39.0	47.0	37.0	55.0	61.0	40.0	41.0	48.0	6.5	9.0	6.5	4.5	66.0	74.0	44.0	136.0	81.0	82.0	69.0	114.0	65.0	37.0	46.0	55.0	37.0	75.0	23.0	13.0	44.0	46.0	44.0	54.0	28.0	38.0	37.0	45.0	44.0	40.0	49.0	25.0	138.0	196.0	47.0	101.0	78.0	121.0	100.0	87.0	54.0	58.0	90.0	72.0	26.0	32.0	53.0	40.0	27.0	43.0	100.0	33.0	32.0	43.0	47.0	34.0	51.0	40.0	37.0	31.0	43.0	40.0	50.0	61.0	69.0	68.0	14.0	39.0	46.0	83.0	52.0	66.0	55.0	50.0	46.0	63.0	94.0	106.0]';
units.LW   = {'cm', 'g'};  label.LW = {'total length','wet weight'};  
bibkey.LW = 'fishbase';
comment.LW = 'total length and wet weight were measured at the same time';

%% set weights for all real data
weights = setweights(data, []);

%% set pseudodata and respective weights
[data, units, label, weights] = addpseudodata(data, units, label, weights);

%% pack auxData and txtData for output
auxData.temp = temp;
txtData.units = units;
txtData.label = label;
txtData.bibkey = bibkey;
txtData.comment = comment;

%% References
bibkey = 'Wiki'; type = 'Misc'; bib = ...
'howpublished = {\url{http://en.wikipedia.org/wiki/my_pet}}';
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'Kooy2010'; type = 'Book'; bib = [ ...  % used in setting of chemical parameters and pseudodata
'author = {Kooijman, S.A.L.M.}, ' ...
'year = {2010}, ' ...
'title  = {Dynamic Energy Budget theory for metabolic organisation}, ' ...
'publisher = {Cambridge Univ. Press, Cambridge}, ' ...
'pages = {Table 4.2 (page 150), 8.1 (page 300)}, ' ...
'howpublished = {\url{http://www.bio.vu.nl/thb/research/bib/Kooy2010.html}}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'fishbase'; type = 'Misc'; bib = [ ...
'author = {Anonymous}, ' ...
'year = {2015}, ' ...
'howpublished = {\url{http://www.fishbase.org/summary/Rhincodon-typus.html}}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
%
bibkey = 'Hour2015'; type = 'Misc'; bib = [ ...
'author = {Handjar Houria}, ' ...
'year = {2015}, ' ...
'note = {Data from Handjar Houria}}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];

